@@ -6,9 +6,10 @@ import argparse
 import logging
 
 from ccb.recipe import get_recipes_list
-from ccb.status import print_status_table, update_status_issue
+from ccb.status import print_status_table
 from ccb.update import update_recipes
 from ccb.github import set_github_token
+from ccb.actions import update_status_issue
 
 
 def bad_command(args, parser):
@@ -32,8 +33,9 @@ def cmd_update(args):
         choose_version=args.choose_version,
         folder=args.folder,
         run_test=not args.no_test,
-        push=args.push,
+        push_to=args.push_to,
         force=args.force,
+        allow_interaction=True,
     )
 
 
@@ -41,8 +43,9 @@ def cmd_update_status_issue(args):
     return update_status_issue(
         cci_path=args.cci,
         issue_url_list=args.issue_url,
-        jobs=int(args.jobs),
-        dry_run=args.dry_run,
+        force=args.force,
+        push_to=args.push_to,
+        status_jobs=int(args.jobs),
     )
 
 
@@ -134,9 +137,7 @@ def main():
         "--folder",
         help="Choose which recipe folder to use (default to the latest)",
     )
-    parser_update.add_argument(
-        "--push", action="store_true", help="Push the new branch to origin"
-    )
+    parser_update.add_argument("--push-to", help="Remote name to push new branches to")
     parser_update.add_argument(
         "--no-test", action="store_true", help="Do not test the updated recipe"
     )
@@ -148,15 +149,19 @@ def main():
         cmd_update_status_issue,
         help="Update the status issue",
     )
-    parser_uis.add_argument("issue_url", nargs="+", help="URL of the issue to update")
+    parser_uis.add_argument("issue_url", nargs="*", help="URL of the issues to update")
+    parser_uis.add_argument(
+        "--force",
+        "-f",
+        action="store_true",
+        help="Overwrite the branch if it exists, force push if the remote branch exists.",
+    )
+    parser_uis.add_argument("--push-to", help="Remote name to push new branches to")
     parser_uis.add_argument(
         "--jobs",
         "-j",
         default=str(10 * os.cpu_count()),
-        help="Number of parallel processes.",
-    )
-    parser_uis.add_argument(
-        "--dry-run", action="store_true", help="Don't update the issue."
+        help="Number of parallel processes during status fetch.",
     )
 
     args = parser.parse_args()
