@@ -1,17 +1,16 @@
 import os
-import yaml
 import typing
 import inspect
 import logging
-import subprocess
 import importlib.util
 from functools import cached_property, lru_cache
 
 from conans import ConanFile
+from ruamel.yaml import YAML
 
 from .version import Version
 from .upstream_project import get_upstream_project
-from .cci import cci_interface, LibPullRequest
+from .cci import cci_interface
 
 
 logger = logging.getLogger(__name__)
@@ -55,13 +54,8 @@ class Status(typing.NamedTuple):
             and self.upstream_version.is_date != self.recipe_version.is_date
         )
 
-    def pr_opened(self):
-        pr = cci_interface.libraries_pull_requests().get(self.name)
-        if pr is None:
-            return None
-        if pr.version == self.upstream_version or pr.version == self.recipe_version:
-            return pr.pr
-        return None
+    def prs_opened(self):
+        return cci_interface.pull_request_for(self)
 
 
 class Recipe:
@@ -69,13 +63,15 @@ class Recipe:
         self.name = name
         self.path = os.path.join(cci_path, "recipes", name)
         self.config_file_path = os.path.join(self.path, "config.yml")
+        self.config_yaml = YAML()
+        self.config_yaml.preserve_quotes = True
 
     def config(self):
         if not os.path.exists(self.config_file_path):
             raise RecipeError("No config.yml file")
 
         with open(self.config_file_path) as fil:
-            return yaml.load(fil, Loader=yaml.FullLoader)
+            return self.config_yaml.load(fil)
 
     @cached_property
     def upstream(self):
